/** @license
 * Copyright (c) 2010-2015 iNTERFACEWARE Inc.  All rights reserved.
 */

function initIfwareSettings() {
   var OriginalCI = clearInterval;
   clearInterval = function(ID) {
      console.log("Clearing interval " + ID);
      OriginalCI(ID);
   }

   $("#main").html("");
   ifware = window.ifware || {};
   ifware.Settings = ifware.Settings || {};
   ifware.SettingsScreen = new SettingsScreen_Class(document.location.hash);
   ifware.SettingsScreen.init();
}

/**
 * @constructor
 */
// Adding the _Class just to make sure we avoid confusion/clashing. It was
// conflicting with the name of the object after refactoring WebConfig to be
// general SettingsScreen helpers.
var SettingsScreen_Class = function(Hash) {
   console.log("Constructing");
   var m_Location  = Hash;
   var m_DefaultPage = "/settings_menu";
   var m_Page        = m_DefaultPage;
   var m_Me          = this;

   function load() {
      console.log(m_Page);
      $.ajax({
         dataType: "json",
         url:      m_Page,
         success:  m_Me.display,
         error:    m_Me.handleError
      });
   }

   function buildTitle(Response) {
      var ServerLabel = Response.server_label
                        ? ' (' + Response.server_label + ')'
                        : '';
      var Title = Response.title 
                  ? ' &gt; ' + Response.title
                  : '';
      return "Iguana" + ServerLabel + Title;
   }

   function displayError(RequestObject) {
      m_Me.display(RequestObject.responseJSON);
      var ErrorMessage = RequestObject.responseJSON.error
                       ? RequestObject.responseJSON.error.description
                       : RequestObject.status + " - " + RequestObject.statusText;

      $('#scResponseDlg').remove();
      $("body").append($(  "<div id='scResponseDlg'>"
                        +  "  <div class='sc_error'></div><br/>"
                        +  "  <div class='sc_output'></div>"
                        +  "  <div class='sc_info'></div>"
                        +  "</div>"));

      var ResponsePopup = $("#scResponseDlg");
      var DlgButtons = {};

      DlgButtons['Close'] = function() {
         $(this).dialog('close');
      }

      ResponsePopup.dialog({
         bgiframe: true,
         width: 600,
         title: "Error",
         modal: true,
         autoOpen: false,
         buttons: DlgButtons,
         close: function(event, ui) {
            document.location = "/";
         }
      });

      ResponsePopup.find('.sc_error').text(ErrorMessage);
      ResponsePopup.find('.sc_error').show();
      ResponsePopup.dialog("open");
   }

   function route() {
      console.log("Routing");
      if (! m_Location) {
         if (document.location.pathname == "/channel") {
            m_Page = '/channel/add';
         } else {
            m_Page = m_DefaultPage;
         }
         load();
         return;
      }
      var Parts = m_Location.split('#');
      console.log(Parts);
      if (Parts.length < 2) {
         m_Page = m_DefaultPage;
         load();
         return;
      }
      if (document.location.pathname == "/channel") {
         console.log(Parts);
         Parts.shift();
         m_Page = "/channel/control?" + Parts.join(encodeURIComponent('#'));
         console.log(m_Page);
         load();
         return;
      } 
      var QueryString = Parts[1].split('=');
      var Start = QueryString.shift();
      if (Start == "Page") {
         m_Page = "/" + QueryString.join('=');
      } else {
         m_Page = m_DefaultPage;
      }
      load();
    }

   function buildParams(Qstring) {
      var Parts = Qstring.split('=');
      var Params = {};
      for (var i = 0; i < Parts.length; i = i + 2) {
         Params[Parts[i]] = Parts[i+1]; 
      }
      return Params;
   }

   function checkForHashChange() {
      console.log(document.location.hash);
      console.log("Hash change");
      m_Location = document.location.hash;
      route();
   }

   // BEGIN: Public API
   this.init = function() {
      $("#fileBrowser ul.jQueryFileTree li a").click(function(event) {
         event.stopPropagation();
      });
      route();
      if ('onhashchange' in window && ( document.documentMode === undefined || document.documentMode > 7 )) {
         window.onhashchange = checkForHashChange;
      } else {
         setInterval(PAGcheckForHashChange, 100);
      }
   }
   this.display = function(Response, TextStatus, RequestObject) {
      console.log("Running display");
      if ( ! Response) {
         console.log("This shouldn't happen, yet it does. Try to find out why.");
      }

      if (Response.location) {
         document.location = Response.location;
      }

      if (Response.body) {
         $("#main").html(Response.body);
         if (Response.title) {
            $("title").html(buildTitle(Response));
         }
      }
   }
   this.handleError = function(RequestObject, Status, ErrorString) {
      console.log("Handling error");
      console.log(RequestObject);
      switch(RequestObject.status) {
         case 401:
            document.location = "/login.html?RedirectLocation=/settings?Page=" + m_Page.substring(1);
            break;
         case 400: 
            displayError(RequestObject);
            break;
         case 402:
         case 403:
         case 404:
            document.location = "/settings";
            break;
         case 500:
            displayError(RequestObject);
            break;
      }
   }
   this.cancel = function(Target) {
      VALfieldValidationFunctions = [];
      if (Target) {
         m_Page = Target;
      }
      load();
   }
   this.page = function() {
      return m_Page;
   }
   // END: Public API
}


